<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>ReminderDialog</name>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="35"/>
        <source>Restart the computer to use the system and the applications properly</source>
        <translation>Перезавантажте комп&apos;ютер, щоб правильно використовувати систему та програми</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="36"/>
        <source>Make sure all data had been saved first</source>
        <translation>Переконайтеся спочатку, що всі дані були збережені</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="41"/>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="41"/>
        <source>Shut down</source>
        <translation>Вимкнути</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="44"/>
        <source>Reboot</source>
        <translation>Перезавантажити</translation>
    </message>
</context>
</TS>